/************************************************************************
 *   IRC - Internet Relay Chat, src/dump.h
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
#ifndef INCLUDED_dump_h
#define INCLUDED_dump_h

#include <time.h>

#include <sys/types.h>
#include <unistd.h>

struct Client;

struct client_connect_record
{
  char *host;
  time_t when;
  time_t until;
  char *reason;
  char *placed_by;

  u_int16_t priority;

  time_t time_deleted; /* When this is non-zero, the record has been deleted and
			*  will eventually be expired
			*/
  char *deleted_by;

  char *spoof_host;
  char *passwd;

  u_int16_t class;

  u_int32_t flags;
};

/* Assorted flags on client connections */
#define CCONNECT_FLAGS_NO_TILDE         0x00000001 /* user, not ~user, even when ident fails */
#define CCONNECT_FLAGS_NEED_IDENT       0x00000002 /* ie: drop connections without it */
#define CCONNECT_FLAGS_ALLOW_BOTS       0x00000080 /* Prevents bot checking code from blocking connections */
#define CCONNECT_FLAGS_SPOOF            0x00000100

/*
 * This number represents the number of non-wildcard characters
 * that must be in the deny ccr string in order for it to be
 * considered valid. KWILD_C in the table at the bottom of match.c
 * indicates a wild character for these purposes.
 */

#define NONWILDCHARS 4

struct ip_drop_record
{
  unsigned long ip;
  unsigned long ip_mask;

  time_t until;

  time_t placed_at;
  char *placed_by;

  time_t deleted_at;
  char *deleted_by;

  char *reason;

  int exception;

  struct ip_drop_record *next;
};

#endif /* INCLUDED_dump_h */
